@@ -3,4 +3,4 @@ from .editor import EditorSerializer
 from .epub import EpubSerializer
 from .hfml import HFMLSerializer
 from .pedurma import PedurmaSerializer
-from .rdf import Rdf
+from .rdf import BUDARDFSerializer
